SnapIT class

Constructors

SnapIT()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

launchTryOnFlow({required BuildContext context, required String apiKey, required String userId, required String garmentImageUrl, String? productId, String? externalUserId, Map<String, dynamic>? metadata, String? modelName = 'fast', double? version = 1.1, SnapITTheme theme = const SnapITTheme(), Future<void> onDownloadImage(String imageUrl)?, required void onSuccess(String resultImageUrl, String generationId), required void onFailure(String errorMessage)}) → void
Opens the Try-On UI experience in the app. Launches a full-screen view where the user can capture/select a photo, triggers upload & try-on generation, and visualizes the results with an interactive slider.